@@ -1,21 +1,7 @@
 /*
-    Copyright 2011 Ilia Kats <ilia-kats@gmx.net>
+    SPDX-FileCopyrightText: 2011 Ilia Kats <ilia-kats@gmx.net>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #ifndef NETWORKMANAGERQT_ACTIVECONNECTION_P_H
@@ -34,6 +20,7 @@ public:
     explicit ActiveConnectionPrivate(const QString &, ActiveConnection *q);
     virtual ~ActiveConnectionPrivate();
     static NetworkManager::ActiveConnection::State convertActiveConnectionState(uint);
+    static NetworkManager::ActiveConnection::Reason convertActiveConnectionReason(uint);
     NetworkManager::Connection::Ptr connection;
     QString path;
     bool default4;
@@ -73,6 +60,7 @@ public:
 
 public Q_SLOTS:
     void propertiesChanged(const QVariantMap &properties);
+    void stateChanged(uint state, uint reason);
 
 private Q_SLOTS:
     void dbusPropertiesChanged(const QString &interfaceName, const QVariantMap &properties, const QStringList &invalidatedProperties);
